[−][src]Module apt_pkg_native::simple
Some structs representing basic concepts, and utilities to copy out of "iterators".
Structs
| BinaryPackage | |
| BinaryPackageVersions | |
| Origin | |
| Version | |
| VersionOrigins |
Some structs representing basic concepts, and utilities to copy out of "iterators".
| BinaryPackage | |
| BinaryPackageVersions | |
| Origin | |
| Version | |
| VersionOrigins |